==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/en_GB.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info not available",
    "Load average: {cpu} (last minute)" : "Load average: {cpu} (last minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}",
    "RAM info not available" : "RAM info not available",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}",
    "SWAP info not available" : "SWAP info not available",
    "Copied!" : "Copied!",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "System" : "System",
    "Monitoring" : "Monitoring",
    "Monitoring app with useful server information" : "Monitoring app with useful server information",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc.",
    "Operating System:" : "Operating System:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Unknown Processor",
    "Memory:" : "Memory:",
    "Server time:" : "Server time:",
    "Uptime:" : "Uptime:",
    "Temperature" : "Temperature",
    "Load" : "Load",
    "Memory" : "Memory",
    "Disk" : "Disk",
    "Mount:" : "Mount:",
    "Filesystem:" : "Filesystem:",
    "Size:" : "Size:",
    "Available:" : "Available:",
    "Used:" : "Used:",
    "Files:" : "Files:",
    "Storages:" : "Storages:",
    "Free Space:" : "Free Space:",
    "Network" : "Network",
    "Hostname:" : "Hostname:",
    "DNS:" : "DNS:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Speed:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Active users",
    "Total users:" : "Total users:",
    "24 hours:" : "24 hours:",
    "1 hour:" : "1 hour:",
    "5 mins:" : "5 mins:",
    "Shares" : "Shares",
    "Users:" : "Users:",
    "Groups:" : "Groups:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated sent:",
    "Federated received:" : "Federated received:",
    "Talk conversations:" : "Talk conversations:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Memory limit:",
    "Max execution time:" : "Max execution time:",
    "Upload max size:" : "Upload max size:",
    "OPcache Revalidate Frequency:" : "OPcache Revalidate Frequency:",
    "Extensions:" : "Extensions:",
    "Unable to list extensions" : "Unable to list extensions",
    "Show phpinfo" : "Show phpinfo",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "External monitoring tool",
    "Use this end point to connect an external monitoring tool:" : "Use this end point to connect an external monitoring tool:",
    "Copy" : "Copy",
    "Output in JSON" : "Output in JSON",
    "Skip app updates (including app updates will send an external request to the app store)" : "Skip app updates (including app updates will send an external request to the app store)",
    "Skip server update" : "Skip server update",
    "To use an access token, please generate one then set it using the following command:" : "To use an access token, please generate one then set it using the following command:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Then pass the token with the \"NC-Token\" header when querying the above URL."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/en_GB.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU info not available",
    "CPU Usage:" : "CPU Usage:",
    "Load average: {percentage} % ({load}) last minute" : "Load average: {percentage} % ({load}) last minute",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes",
    "RAM Usage:" : "RAM Usage:",
    "SWAP Usage:" : "SWAP Usage:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}",
    "RAM info not available" : "RAM info not available",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}",
    "SWAP info not available" : "SWAP info not available",
    "Copied!" : "Copied!",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "System" : "System",
    "Monitoring" : "Monitoring",
    "Monitoring app with useful server information" : "Monitoring app with useful server information",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc.",
    "Operating System:" : "Operating System:",
    "CPU:" : "CPU:",
    "threads" : "threads",
    "Memory:" : "Memory:",
    "Server time:" : "Server time:",
    "Uptime:" : "Uptime:",
    "Temperature" : "Temperature",
    "Load" : "Load",
    "Memory" : "Memory",
    "Disk" : "Disk",
    "Mount:" : "Mount:",
    "Filesystem:" : "Filesystem:",
    "Size:" : "Size:",
    "Available:" : "Available:",
    "Used:" : "Used:",
    "Files:" : "Files:",
    "Storages:" : "Storages:",
    "Free Space:" : "Free Space:",
    "Network" : "Network",
    "Hostname:" : "Hostname:",
    "Gateway:" : "Gateway:",
    "Status:" : "Status:",
    "Speed:" : "Speed:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Active users",
    "Last hour" : "Last hour",
    "%s%% of all users" : "%s%% of all users",
    "Last 24 Hours" : "Last 24 Hours",
    "Last 7 Days" : "Last 7 Days",
    "Last 30 Days" : "Last 30 Days",
    "Shares" : "Shares",
    "Users:" : "Users:",
    "Groups:" : "Groups:",
    "Links:" : "Links:",
    "Emails:" : "Emails:",
    "Federated sent:" : "Federated sent:",
    "Federated received:" : "Federated received:",
    "Talk conversations:" : "Talk conversations:",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory limit:" : "Memory limit:",
    "Max execution time:" : "Max execution time:",
    "Upload max size:" : "Upload max size:",
    "OPcache Revalidate Frequency:" : "OPcache Revalidate Frequency:",
    "Extensions:" : "Extensions:",
    "Unable to list extensions" : "Unable to list extensions",
    "Show phpinfo" : "Show phpinfo",
    "FPM worker pool" : "FPM worker pool",
    "Pool name:" : "Pool name:",
    "Pool type:" : "Pool type:",
    "Start time:" : "Start time:",
    "Accepted connections:" : "Accepted connections:",
    "Total processes:" : "Total processes:",
    "Active processes:" : "Active processes:",
    "Idle processes:" : "Idle processes:",
    "Listen queue:" : "Listen queue:",
    "Slow requests:" : "Slow requests:",
    "Max listen queue:" : "Max listen queue:",
    "Max active processes:" : "Max active processes:",
    "Max children reached:" : "Max children reached:",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "External monitoring tool",
    "Use this end point to connect an external monitoring tool:" : "Use this end point to connect an external monitoring tool:",
    "Copy" : "Copy",
    "Output in JSON" : "Output in JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Skip apps section (including apps section will send an external request to the app store)",
    "Skip server update" : "Skip server update",
    "To use an access token, please generate one then set it using the following command:" : "To use an access token, please generate one then set it using the following command:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Then pass the token with the \"NC-Token\" header when querying the above URL.",
    "Unknown Processor" : "Unknown Processor"
},
"nplurals=2; plural=(n != 1);");
